@@ -1,3 +1,4 @@
+from .base import BaseLoRa
 import spidev
 import RPi.GPIO
 import time
@@ -7,7 +8,8 @@ gpio = RPi.GPIO
 gpio.setmode(RPi.GPIO.BCM)
 gpio.setwarnings(False)
 
-class SX126x :
+class SX126x(BaseLoRa) :
+    """Class for SX1261/62/68 and LLCC68 LoRa chipsets from Semtech"""
 
     # SX126X register map
     REG_FSK_WHITENING_INITIAL_MSB          = 0x06B8
@@ -309,7 +311,7 @@ class SX126x :
         spi.close()
         gpio.cleanup()
 
-    def reset(self) :
+    def reset(self) -> bool :
 
         # put reset pin to low then wait busy pin to low
         gpio.output(self._reset, gpio.LOW)
@@ -410,7 +412,8 @@ class SX126x :
         self.setRegulatorMode(regMode)
 
     def setCurrentProtection(self, level) :
-
+        #avoid wrap-around of OCP register, which has 6bits
+        if level > 63 : level = 63
         self.writeRegister(self.REG_OCP_CONFIGURATION, (level,), 1)
 
 ### MODEM, MODULATION PARAMETER, AND PACKET PARAMETER SETUP METHODS ###
@@ -646,7 +649,7 @@ class SX126x :
             gpio.output(self._rxen, gpio.LOW)
         self._fixLoRaBw500(self._bw)
 
-    def endPacket(self, timeout: int = TX_SINGLE, intFlag: bool = True) -> bool :
+    def endPacket(self, timeout: int = TX_SINGLE) -> bool :
 
         # skip to enter TX mode when previous TX operation incomplete
         if self.getMode == self.STATUS_MODE_TX : return False
@@ -668,7 +671,7 @@ class SX126x :
         self._transmitTime = time.time()
 
         # set operation status to wait and attach TX interrupt handler
-        if self._irq != -1 and intFlag :
+        if self._irq != -1 :
             gpio.remove_event_detect(self._irq)
             gpio.add_event_detect(self._irq, gpio.RISING, callback=self._interruptTx, bouncetime=10)
         return True
@@ -702,7 +705,7 @@ class SX126x :
 
 ### RECEIVE RELATED METHODS ###
 
-    def request(self, timeout: int = RX_SINGLE, intFlag: bool = True) -> bool :
+    def request(self, timeout: int = RX_SINGLE) -> bool :
 
         # skip to enter RX mode when previous RX operation incomplete
         if self.getMode() == self.STATUS_MODE_RX : return False
@@ -731,7 +734,7 @@ class SX126x :
         self.setRx(rxTimeout)
 
         # set operation status to wait and attach RX interrupt handler
-        if self._irq != -1 and intFlag :
+        if self._irq != -1 :
             gpio.remove_event_detect(self._irq)
             if timeout == self.RX_CONTINUOUS :
                 gpio.add_event_detect(self._irq, gpio.RISING, callback=self._interruptRxContinuous, bouncetime=10)
@@ -739,7 +742,7 @@ class SX126x :
                 gpio.add_event_detect(self._irq, gpio.RISING, callback=self._interruptRx, bouncetime=10)
         return True
 
-    def listen(self, rxPeriod: int, sleepPeriod: int, intFlag: bool = True) -> bool :
+    def listen(self, rxPeriod: int, sleepPeriod: int) -> bool :
 
         # skip to enter RX mode when previous RX operation incomplete
         if self.getMode() == self.STATUS_MODE_RX : return False
@@ -767,7 +770,7 @@ class SX126x :
         self.setRxDutyCycle(rxPeriod, sleepPeriod)
 
         # set operation status to wait and attach RX interrupt handler
-        if self._irq != -1 and intFlag :
+        if self._irq != -1 :
             gpio.remove_event_detect(self._irq)
             gpio.add_event_detect(self._irq, gpio.RISING, callback=self._interruptRx, bouncetime=10)
         return True
@@ -821,19 +824,21 @@ class SX126x :
     def wait(self, timeout: int = 0) -> bool :
 
         # immediately return when currently not waiting transmit or receive process
-        if self._statusIrq != 0x0000 :
-            return False
+        if self._statusIrq :
+            return True
+
         # wait transmit or receive process finish by checking IRQ status
         irqStat = 0x0000
         t = time.time()
         while irqStat == 0x0000 and self._statusIrq == 0x0000 :
-            irqStat = self.getIrqStatus()
+            # only check IRQ status register for non interrupt operation
+            if self._irq == -1 : irqStat = self.getIrqStatus()
             # return when timeout reached
             if (time.time() - t) > timeout and timeout > 0 : return False
-        
+
         if self._statusIrq :
             # immediately return when interrupt signal hit
-            return False
+            return True
         elif self._statusWait == self.STATUS_TX_WAIT :
             # for transmit, calculate transmit time and set back txen and rxen pin to previous state
             self._transmitTime = time.time() - self._transmitTime
@@ -851,7 +856,7 @@ class SX126x :
             # for receive continuous, get received payload length and buffer index and clear IRQ status
             (self._payloadTxRx, self._bufferIndex) = self.getRxBufferStatus()
             self.clearIrqStatus(0x03FF)
-        
+
         # store IRQ status
         self._statusIrq = irqStat
         return True
